/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of HumanResources **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-03-31 10:21+0200\nLast-Translator: Paul Hartog <p.hartog@metaways.de>\nLanguage-Team: German (http://www.transifex.com/tine20/tine20/language/de/)\nLanguage: de\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-SourceCharset: utf-8\nX-Generator: Poedit 2.3\n"

, "You do not have admin rights on HumanResources"
: "Sie haben keine Administratorenrechte am Modul Human Ressources"

, "Working time model"
: "Arbeitszeitmodell"

, "Book as vacation"
: "Als Urlaub buchen"

, "Sickness"
: "Krankheit"

, "Sickness Days"
: "Krankheitstage"

, "Vacation"
: "Urlaub"

, "Vacation Days"
: "Urlaubstage"

, "There could not be found any {0}. Please try to change your filter-criteria or view-options."
: "Es konnte keine {0} gefunden werden. Bitte ändern Sie die Filterkriterien oder Ansichtseinstellungen."

, "Could not book as vacation"
: "Konnte nicht als Urlaub gebucht werden"

, "The unexcused sickness days could not be booked as vacation. There are not enough days left!"
: "Die unentschuldigten Krankheitstage konnten nicht als Urlaub gebucht werden, da keine Urlaubstage mehr übrig sind!"

, "Human Resources, Human Resources"
: [
  ""
 ,""

]
, "Title"
: "Titel"

, "Work Start"
: "Arbeitsbegin"

, "Work End"
: "Arbeitsende"

, "Edit {0} for {1} - {2}"
: "{0} von {1} des Jahres {2} bearbeiten"

, "Extra free time, Extra free times"
: [
  "Sonderurlaub"
 ,"Sonderurlaube"

]
, "Summary"
: "Zusammenfassung"

, "Free Times"
: "Freie Tage"

, "Possible vaction days"
: "Mögliche Urlaubstage"

, "Remaining vaction days"
: "Übrige Urlaubstage"

, "Taken vaction days"
: "Verbrauchte Urlaubstage"

, "Expired vaction days"
: "Verfallene Urlaubstage"

, "Rebooked vaction days"
: "Umgebuchte Urlaubstage"

, "Excused sickness days"
: "Entschuldigte Krankheitstage"

, "Unexcused sickness days"
: "Unentschuldigte Krankheitstage"

, "Working Time"
: "Arbeitszeit"

, "Days to work"
: "Anzahl Arbeitstage"

, "Hours to work"
: "Anzahl der zu leistenden Stunden"

, "Days to work after vacation and sickness"
: "Arbeitstage nach Urlaub und Krankheit"

, "Hours to work after vacation and sickness"
: "Zu leistende Stunden nach Urlaub und Krankheit"

, "Miscellaneous"
: "Verschiedenes"

, "Description"
: "Beschreibung"

, "not set"
: "Nicht gesetzt"

, "Working Hours per week"
: "Arbeitsstunden pro Woche"

, "Mon."
: "Mo."

, "Tue."
: "Di."

, "Wed."
: "Mi."

, "Thu."
: "Do."

, "Fri."
: "Fr."

, "Sat."
: "Sa."

, "Sun."
: "So."

, "Employee, Employees"
: [
  "Mitarbeiter"
 ,"Mitarbeiter"

]
, "Cancel"
: "Abbrechen"

, "OK"
: "OK"

, "Please use the following format: MM-DD"
: "Bitte das folgende Format verwenden: MM-TT"

, "Calendar"
: "Kalender"

, "Calendars"
: "Kalender"

, "Vacation expires"
: "Urlaub verfällt"

, "Breaks"
: "Pausen"

, "Hours"
: "Stunden"

, "Break duration"
: "Pausenzeit"

, "Book remaining vacation"
: "Urlaub vom letzten Jahr als Sonderurlaub buchen"

, "Year"
: "Jahr"

, "Please enter the year you want to create accounts for:"
: "Bitte geben Sie das Jahr an, für das Personalkonten erzeugt werden sollen:"

, "Accounts have been created"
: "Konten wurden angelegt"

, "{0} accounts for the year {1} have been created successfully!"
: "{0} Konten wurden im Jahr {1} erfolgreich erstellt!"

, "Create new accounts"
: "Personalkonten anlegen"

, "Booking has been successfull!"
: "Buchung erfolgreich!"

, "The remaining vacation days of the selected accounts have been booked successfully!"
: "Die übrigen Urlaubstage wurden erfolgreich umgebucht!"

, "CostCenter, CostCenters"
: [
  "Kostenstelle"
 ,"Kostenstellen"

]
, "Cost Center, Cost Centers"
: [
  "Kostenstelle"
 ,"Kostenstellen"

]
, "Startdate"
: "Anfangsdatum"

, "Contract, Contracts"
: [
  "Vertrag"
 ,"Verträge"

]
, "Vacation in same period"
: "Urlaub im selben Zeitraum"

, "There are some vacation days matching the period of the contract you added. After saving this employee, changing the contract is not possible anymore."
: "Es gibt Urlaubstage die zu dem Zeitraum des hinzugefügten Vertrags passen. Nachdem der Mitarbeiter gespeichert wurde, kann der Vertrag nicht mehr geändert werden."

, "Edit {0}"
: "{0} bearbeiten"

, "Start Date"
: "Anfang"

, "End Date"
: "Ende"

, "Feast Calendar"
: "Feiertagskalender"

, "Choose the template"
: "Vorlage auswählen"

, "Vacation days of one calendar year"
: "Urlaubstage eines Kalenderjahrs"

, "Edit {0} \"{1}\""
: "{0} \"{1}\" bearbeiten"

, "Edit {0} for {1}"
: "{0} für {1} bearbeiten"

, "Add {0} for {1}"
: "Füge {0} für {1} hinzu"

, "You have to select at least one day to save this sickness entry."
: "Sie müssen mindestens einen Tag auswählen, um diesen Kranksheitseintrag speichern zu können."

, "You have to select at least one day to save this vacation entry."
: "Sie müssen mindestens einen Tag auswählen, um diesen Urlaub speichern zu können."

, "No day selected"
: "Kein Tag ausgewählt"

, "Personal account, Personal accounts"
: [
  "Personalkonto"
 ,"Personalkonten"

]
, "Status"
: "Status"

, "Remaining"
: "Übrig"

, "Select Days"
: "Tage auswählen"

, "Enter description"
: "Geben Sie eine Beschreibung an"

, "Account is disabled or deleted!"
: "Benutzer nicht mehr vorhanden!"

, "Division"
: "Abteilung"

, "Health Insurance"
: "Krankenkasse"

, "Apply contact data on form"
: "Wende Kontaktdaten auf dieses Formular an"

, "Salutation"
: "Anrede"

, "Personal Information"
: "Persönliche Informationen"

, "Country"
: "Land"

, "Birthday"
: "Geburtstag"

, "Internal Information"
: "Interne Informationen"

, "Banking Information"
: "Bankverbindung"

, "Days"
: "Tage"

, "Type"
: "Typ"

, "Expiration date"
: "Ablaufdatum"

, "WK"
: "KW"

, "Loading calendar data..."
: "Lade Kalender…"

, "Year can not be changed"
: "Das Jahr kann nicht geändert werden"

, "You have already selected some dates from another year. Please create a new record to add dates from another year!"
: "Sie haben bereits ein oder mehrere Tage aus einem anderen Jahr gewählt. Bitte erstellen Sie einen neuen Datensatz, um die gewünschten Tage einzutragen."

, "No more vacation days"
: "Keine weiteren Urlaubstage vorhanden"

, "The Employee has no more possible vacation days left for this year. Create a new vacation and use another personal account the vacation should be taken from."
: "Der Mitarbeiter hat keine Urlaubstage auf dem gewünschten Personalkonto. Erstellen Sie einen neuen Urlaub und wählen Sie ein anderes Personalkonto, von dem die Urlaubstage abgezogen werden sollen."

, "Excused"
: "Entschuldigt"

, "Unexcused"
: "Unentschuldigt"

, "Currently employed"
: "Momentan angestellt"

, "Employees which are currently employed"
: "Momentan angestellte Mitarbeiter"

, "All employees"
: "Alle Angestellten"

, "All available employees"
: "Alle verfügbaren Mitarbeiter"

, "Payed"
: "Bezahlt"

, "Not payed"
: "Unbezahlt"

, "Currently employed employees"
: "Zur Zeit angestellt"

, "All accounts"
: "Alle Konten"

, "All available accounts"
: "Alle verfügbaren Benutzerkonten"

, "Full-time 40 hours"
: "Vollzeit 40 Stunden"

, "Full-time 37.5 hours"
: "Vollzeit 37,5 Stunden"

, "Part-time 20 hours"
: "Teilzeit 20 Stunden"

, "Freetime Type"
: "Freizeitanspruch Typ"

, "Possible free time definitions"
: "Mögliche Definitionen für Freie Zeit"

, "Vacation Status"
: "Urlaubsstatus"

, "Possible vacation status definitions"
: "Mögliche Definitionen des Urlaubsstatus"

, "Requested"
: "Angefragt"

, "In process"
: "In Bearbeitung"

, "Accepted"
: "Akzeptiert"

, "Declined"
: "Abgewiesen"

, "Sickness Status"
: "Krankheitsstatus"

, "Possible sickness status definitions"
: "Mögliche Definitionen von Krankheiten"

, "Default Feast Calendar"
: "Standard-Feiertagskalender"

, "Here you can define the default feast calendar used to set feast days and other free days in datepicker"
: "Hier können Sie den Standard-Feiertagskalender festlegen, der verwendet wird, um Feiertage und andere freie Tage in der Datumsauswahl anzuzeigen"

, "Enabled Features"
: "Aktiviertes Features"

, "Enabled Features in HumanResources Application."
: "Aktivierte Funktionen in der HumanResources Anwendung."

, "Calculate Daily Reports"
: "Tägliche Berichte berechnen"

, "Activate to calculate daily reports with a nightly scheduler job"
: "Aktivieren Sie diese Option, um tägliche Berichte zu Berechnen. (Berechnung geschieht über Nacht)"

, "Extra freetime type"
: "Sonderurlaub Typ"

, "Possible extra free time definitions"
: "Mögliche Sonderurlaube"

, "Here you can define the day, when the vacation days taken from last year expires, the format is MM-DD."
: "Hier können Sie den Tag angeben, ab dem die Urlaubstage vom letzten Jahr verfallen sind. Bitte im Format MM-TT angeben."

, "Report Templates Node ID"
: "Berichtsvorlagen Node ID"

, "Timetracker Timeaccount for Workingtime Tracking"
: "Zeit-Tracker der Zeitkonten für die Arbeitszeiterfassung"

, "Daily Working Time Report, Daily Working Time Reports"
: [
  "Täglicher Arbeitszeitbericht"
 ,"Tägliche Arbeitszeitberichte"

]
, "Date"
: "Datum"

, "Evaluation Start Time"
: "Auswertungsstartzeit"

, "Evaluation End Time"
: "Auswertungsendzeit"

, "Paid Absence Time"
: "Bezahlter Urlaub"

, "Unpaid Absence Time"
: "Unbezahlter Urlaub"

, "Absence"
: "Abwesenheit"

, "Break Time Net"
: "Pausenzeit (Netto)"

, "Break Deduction Time"
: "Pausenzeit Abzug"

, "Feast Time"
: ""

, "Break Time"
: "Pausenzeit"

, "Sickness Time"
: "Tage der Krankmeldung"

, "Working Time Correction"
: "Arbeitszeitkorrektur"

, "Actual Working Time"
: "Arbeitszeit (Ist)"

, "Target Working Time"
: "Arbeitszeit (Soll)"

, "System Remark"
: "Anmerkung des Systems"

, "Remark"
: "Anmerkung"

, "Is Cleared"
: "Ist Abgerechnet"

, "Cleared in"
: ""

, "Working time, Working times"
: [
  "Arbeitszeit"
 ,"Arbeitszeiten"

]
, "Quick search"
: "Schnellsuche"

, "Extra free times"
: "Sonderurlaub"

, "Free Time, Free Times"
: [
  "Freizeitanspruch"
 ,"Freizeitansprüche"

]
, "Account"
: "Benutzerkonto"

, "First Day"
: "Erster Tag"

, "Last Day"
: "Letzter Tag"

, "Days Count"
: "Anzahl der Tage"

, "Free Days"
: "Freie Tage"

, "Private Information"
: "Private Informationen"

, "Is employed"
: "Ist angestellt"

, "Number"
: "Pers.-Nr."

, "Badge Id"
: ""

, "Germany"
: "Deutschland"

, "Locality"
: "Ort"

, "Postalcode"
: "Postleitzahl"

, "Region"
: "Region"

, "Street"
: "Straße"

, "Street 2"
: "Straße 2"

, "E-Mail"
: "E-Mail"

, "Telephone Number"
: "Telefonnummer"

, "Cell Phone Number"
: "Handynummer"

, "Last Name"
: "Nachname"

, "First Name"
: "Vorname"

, "Employee name"
: "Name des Mitarbeiters"

, "Account Holder"
: "Kontoinhaber"

, "Account Number"
: "Kontonummer"

, "Bank Name"
: "Name der Bank"

, "Code Number"
: "Bankleitzahl"

, "Employment begin"
: "Angestellt von"

, "Employment end"
: "Angestellt bis"

, "Supervisor"
: "Vorgesetzter"

, "Profession"
: "Beruf"

, "Position"
: "Position"

, "Contracts"
: "Verträge"

, "Cost Centers"
: "Kostenstellen"

, "Free Day, Free Days"
: [
  "Freier Tag"
 ,"Freie Tage"

]
, "Break, Breaks"
: [
  "Pause"
 ,"Pausen"

]
, "Workingtime"
: "Arbeitszeit"

, "No contract could be found."
: "Es  konnte kein Vertrag gefunden werden."

, "Please create a contract for this employee!"
: "Bitte erstellen Sie einen Vertrag für diesen Mitarbeiter!"

, "Negative Timespace"
: "Negativer Zeitraum"

, "The start date of the contract must be before the end date!"
: "Der Anfang des Vertrages muss vor dem Ende sein!"

, "Not allowed!"
: "Nicht erlaubt!"

, "It's only allowed to book remaining vacation days from years in the past!"
: "Es ist nur erlaubt, Resturlaub aus vergangenen Jahren zu buchen!"

, "Contracts overlap"
: "Überlappende Verträge"

, "The contracts must not overlap!"
: "Die Verträge dürfen sich nicht überlappen!"

, "No or no valid year given"
: "Kein oder kein valides Jahr angegeben"

, "Please use a valid year!"
: "Bitte geben Sie ein korrektes Jahr an!"

, "No current contract!"
: "Kein aktueller Vertrag!"

, "A current contract could not be found!"
: "Es  konnte kein aktueller Vertrag gefunden werden!"

, "Contract not editable"
: "Vertrag nicht bearbeitbar"

, "You are not allowed to change the record if a vacation has been booked already!"
: "Der Vertrag kann nicht mehr geändert werden, wenn bereits Urlaub gebucht worden ist."

, "No personal account found"
: "Kein Personalkonto gefunden"

, "An existing personal account could not be found. Please create one!"
: "Es konnte kein Personalkonto gefunden werden. Bitte erstellen Sie eines!"

, "edit private employee data"
: "Private Daten des Mitarbeiters bearbeiten"

, "Edit birthday, account data and other private information of employee records"
: "Bearbeiten von persönlichen Daten und Vertragsdaten des Mitarbeiters"

, "Public Holiday Calendar"
: "Feiertagskalender"

, "Here you can define the default public holiday calendar used to set public holidays and other free days in datepicker"
: "Hier können Sie den Standardkalender für Feiertage definieren, mit dem Feiertage und andere freie Tage in der Datumsauswahl festgelegt werden"

, "Public Holidays"
: "Feiertage"

, "Badge ID"
: "Karten ID"

, "Working time Model"
: "Arbeitszeitmodell"

, "Work start"
: "Arbeitsbegin"

, "Work end"
: "Arbeitsende"

, "Feast Days"
: "Feiertage"

, "Wage types"
: "Lohnarten"

, "Free time types"
: "Abwesenheitsarten"

, "Working time scheme, Working time schemes"
: [
  "Arbeitszeitschema"
 ,"Arbeitszeitschemas"

]
, "Template"
: "Vorlage"

, "Individual"
: "Individuell"

, "Shared"
: "Gemeinsam"

, "Calculate all Reports"
: "Berechnen alle Berichte"

, "Recalculate"
: "Neuberechnung"

, "Working Time Rules"
: "Arbeitszeit Regeln"

, "Working Time Schema"
: "Arbeitszeit Schema"

, "Template (individual working time schemas are created for each contract)"
: "Vorlage (für jeden Vertrag wird ein individuelles Arbeitszeitschema angelegt)"

, "Shared (this working time schemas can be shared among contracts)"
: "Gemeinsam (dieses Arbeitszeit Schema kann gemeinsam genutzt werden)"

, "Default wage type"
: "Standard Lohnart"

, "Salary"
: "Gehalt"

, "Business trip"
: "Dienstreise"

, "Sunday bonus"
: "Sonntagszulage"

, "Feast day"
: "Feiertag"

, "Feast day bonus"
: "Feiertagszulage"

, "Overtime"
: "Überstunden"

, "Overtime bonus"
: "Überstundenzulage"

, "Late shift bonus"
: "Spätschichtzulage"

, "Night bonus"
: "Nachtarbeitszulage"

, "Stand by"
: "Bereitschaft"

, "Unpaid"
: "Unbezahlt"

, "[S] Sickness"
: "[K] Krankheit"

, "[D] Visit doctor"
: "[A] Arzt"

, "[V] Vacation"
: "[U] Urlaub"

, "[BT] Business trip"
: "[D] Dienstreise"

, "[FT] Flex time"
: "[G] Gleitzeit"

, "[BK] Break"
: "[P] Pause"

, "[T] Training"
: "[S] Schulung"

, "No valid contract for this date"
: "Für dieses Datum existiert kein gültiger Vertrag"

, "unexpected error: "
: "Unerwarteter Fehler: "

, "daily wt reports can't be created"
: "Tägliche Arbeitszeitberichte können nicht manuell erzeugt werden"

, "It is not allowed to update a cleared report"
: "Abgerechnete Berichte können nicht geändert werden"

, "monthly wt reports can't be created"
: "Monatliche Arbeitszeitberichte können nicht manuell erzeugt werden"

, "previous months need to be cleared first"
: "Sie müssen den Vormonat zuerst abrechnen"

, "following months need to be uncleared first"
: "Sie müssen die Abrechnung des Vormonats zuvor aufheben"

, "Corrected Evaluation Start Time"
: "Korrigierte Auswertungs Startzeit"

, "Corrected Evaluation End Time"
: "Korrigierte Auswertungs Endzeit"

, "Target Working Time Correction"
: "Soll Arbeitszeit Korrektur"

, "Working Times"
: "Arbeitszeiten"

, "Total Working Time"
: "Gesamt Arbeitszeit"

, "Calculation Error"
: "Fehler bei der Berechnung"

, "Monthly Working Time Report, Monthly Working Time Reports"
: [
  "Monatlicher Arbeitszeit Bericht"
 ,"Monatliche Arbeitszeit Berichte"

]
, "Month"
: "Monat"

, "Daily Working Time Reports"
: "Tägliche Arbeitszeit Berichte"

, "Working Time Balance Previous Month"
: "Vormonats Saldo Arbeitszeit"

, "Total Working Time Balance"
: "Gesamt Saldo Arbeitszeit"

, "Wage type, Wage types"
: [
  "Lohnart"
 ,"Lohnarten"

]
, "Abbreviation"
: "Abkürzung"

, "Name"
: "Name"

, "System"
: "System"

, "Factor (%)"
: "Faktor (%)"

, "Additional Wage"
: "Zusatzlohn"

, "Start time"
: "Startzeit"

, "After exceeding {{time_worked|date(\"H:i\", \"GMT\")}} of working time {{break_time|date(\"H:i\", \"GMT\")}} break time gets deducted automatically."
: "Wenn {{time_worked|date(\"H:i\", \"GMT\")}} Arbeitszeit überschritten sind, werden {{break_time|date(\"H:i\", \"GMT\")}} Pausenzeit automatisch abgezogen."

, "Time worked"
: "Arbeitszeit"

, "Break time"
: "Pausenzeit"

, "Work Time Limit, Work Time Limits"
: [
  "Arbeitzeitlimitierung"
 ,"Arbeitzeitlimitierungen"

]
, "Working time is evaluated from {{start_time|date(\"H:i\")}} until {{end_time|date(\"H:i\")}}."
: "Arbeitszeit wird ausgewertet von {{start_time|date(\"H:i\")}} bis {{end_time|date(\"H:i\")}}."

, "Absence reason, Absence reasons"
: [
  "Abwesenheitsgrund"
 ,"Abwesenheitsgründe"

]
, "Allow Booking"
: "Buchung erlauben"

, "Allow Planning"
: "Plaung erlauben"

, "Enable Freetime Timetracking"
: "Abwesenheits-Zeiterfassung aktivieren"

, "Timeaccount"
: "Zeitkonto"

, "Transponder Id"
: "Transponder"

, "Working Time Balance"
: "Arbeitszeit Saldo"

, "[FD] Feast day"
: "[F] Feiertag"

, "Break Times"
: "Pausenzeiten"

, "Work Time Limits"
: "Arbeitzeitlimits"

, "Free Time Planning"
: "Abwesenheitsplanung"

, "Add Free Time"
: "Abwesenheit hinzufügen"

, "Edit Free Time"
: "Abwesenheit bearbeiten"

, "Delete Free Time"
: "Abwesenheit löschen"

, "Freetime"
: "Abwesenheit"

, "Human Resources"
: ""

, "Extra free time"
: "Sonderurlaub"

, "Employee"
: "Mitarbeiter"

, "CostCenter"
: "Kostenstelle"

, "Cost Center"
: "Kostenstelle"

, "Contract"
: "Vertrag"

, "Personal account"
: "Personalkonto"

, "Daily Working Time Report"
: "Täglicher Arbeitszeitbericht"

, "Working time"
: "Arbeitszeit"

, "Free Time"
: "Freizeitanspruch"

, "Free Day"
: "Freier Tag"

, "Break"
: "Pause"

, "Working time scheme"
: "Arbeitszeitschema"

, "Monthly Working Time Report"
: "Monatlicher Arbeitszeit Bericht"

, "Wage type"
: "Lohnart"

, "Work Time Limit"
: "Arbeitzeitlimitierung"

, "Absence reason"
: "Abwesenheitsgrund"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
